@@ -4,10 +4,12 @@ from open_feature.exception.exceptions import GeneralError
 from open_feature.open_feature_client import OpenFeatureClient
 from open_feature.provider.provider import AbstractProvider
 
-_provider = None
+_provider: typing.Optional[AbstractProvider] = None
 
 
-def get_client(name: str = None, version: str = None) -> OpenFeatureClient:
+def get_client(
+    name: typing.Optional[str] = None, version: typing.Optional[str] = None
+) -> OpenFeatureClient:
     if _provider is None:
         raise GeneralError(
             error_message="Provider not set. Call set_provider before using get_client"
