@@ -2,6 +2,7 @@ import typing
 from abc import abstractmethod
 
 from open_feature.evaluation_context.evaluation_context import EvaluationContext
+from open_feature.flag_evaluation.flag_evaluation_details import FlagEvaluationDetails
 from open_feature.hooks.hook import Hook
 from open_feature.provider.metadata import Metadata
 
@@ -20,8 +21,8 @@ class AbstractProvider:
         self,
         flag_key: str,
         default_value: bool,
-        evaluation_context: EvaluationContext = EvaluationContext(),
-    ):
+        evaluation_context: typing.Optional[EvaluationContext] = None,
+    ) -> FlagEvaluationDetails[bool]:
         pass
 
     @abstractmethod
@@ -29,8 +30,8 @@ class AbstractProvider:
         self,
         flag_key: str,
         default_value: str,
-        evaluation_context: EvaluationContext = EvaluationContext(),
-    ):
+        evaluation_context: typing.Optional[EvaluationContext] = None,
+    ) -> FlagEvaluationDetails[str]:
         pass
 
     @abstractmethod
@@ -38,8 +39,8 @@ class AbstractProvider:
         self,
         flag_key: str,
         default_value: int,
-        evaluation_context: EvaluationContext = EvaluationContext(),
-    ):
+        evaluation_context: typing.Optional[EvaluationContext] = None,
+    ) -> FlagEvaluationDetails[int]:
         pass
 
     @abstractmethod
@@ -47,8 +48,8 @@ class AbstractProvider:
         self,
         flag_key: str,
         default_value: float,
-        evaluation_context: EvaluationContext = EvaluationContext(),
-    ):
+        evaluation_context: typing.Optional[EvaluationContext] = None,
+    ) -> FlagEvaluationDetails[float]:
         pass
 
     @abstractmethod
@@ -56,6 +57,6 @@ class AbstractProvider:
         self,
         flag_key: str,
         default_value: dict,
-        evaluation_context: EvaluationContext = EvaluationContext(),
-    ):
+        evaluation_context: typing.Optional[EvaluationContext] = None,
+    ) -> FlagEvaluationDetails[dict]:
         pass
